import { request } from "umi";
import config from "./config";
import { RespResult } from "./core/model/ReqData";
/**
 * 获取token
 * @param code
 */
export function getToken(code: string) {
  return request(`${config.authenticationServiceUrl}/oauth/token`, {
    method: "post",
    params: {
      client_id: "OM90JPKW",
      client_secret: "Pmsu_Qowqm198Uih",
      grant_type: "authorization_code",
      code: code,
      redirect_uri: config.devAppUrl,
    },
  });
}

/**
 * 获取用户信息
 * @param open_id
 * @param token
 * @returns
 */
export function getUserinfo(open_id: number, token: string) {
  return request(`${config.openApiUrl}/oauth/user/info`, {
    method: "get",
    params: {
      open_id: open_id,
      access_token: token,
    },
  });
}

/**
 * 上传文件
 * @param formData
 * @returns
 */
export function uploadFile(formData: FormData) {
  return request<RespResult<{ path: string; name: string }>>(
    `/apis/public/api/uploadMedia`,
    {
      data: formData,
      requestType: "form",
      method: "post",
    }
  );
}
/**
 * 上传表单
 * @param form 表单数据
 * @returns
 */
export function submitForm(form: {
  address: string;
  telphone: number;
  problemDesc: string;
  reporter: string;
  longitude: number;
  latitude: number;
  belongArea: number;
  belongAreaName: string;
  fileNames: string;
  filePaths: string;
}) {
  return request<RespResult<string>>(`/apis/public/api/report`, {
    data: form,
    method: "post",
    requestType: "form",
  });
}

/**
 * 获取报告列表
 * @param phone
 * @param pageSize
 * @returns
 *
 * */
export function getReportList(
  phone: string,
  pageSize: number,
  pageNum: number
) {
  return request<RespResult<any[]>>("/apis/public/api/pageMyReportProblems", {
    method: "get",
    params: {
      telphone: phone,
      pageSize,
      pageNo: pageNum,
    },
  });
}

/**
 *
 * @param id  报告id
 * @returns
 */
export function getReportDetail(id: string) {
  return request<RespResult<any>>("/apis/public/api/queryProblemById", {
    method: "get",
    params: {
      id,
    },
  });
}
