import { request } from "umi";
import config from "./config";
import { RespResult } from "./core/model/ReqData";

/**
 * 高德官方逆地理编码
 * @param location 传入内容规则：经度在前，纬度在后，经纬度间以“,”分割，经纬度小数点后不要超过 6 位。
 */
export async function getGeocode(
  location: (string | number)[]
): Promise<RespResult<any>> {
  return new Promise((resolve) => {
    fetch(
      `https://restapi.amap.com/v3/geocode/regeo?output=json&location=${location.join()}&key=${
        config.mapWebKey
      }`
    )
      .then((response) => response.json())
      .then((data) => {
        // 获取逆地理编码结果，包含实际地址信息
        if (data.status === "1" && data.regeocode) {
          const formattedAddress = data.regeocode.formatted_address;
          resolve({
            data: {
              addres: formattedAddress,
              addressComponent: data.regeocode.addressComponent,
            },
          });
        }
      });
  });
}

/** 高德官方位置搜索api */
export function getInfoByCoords(keywords: string, city: string) {
  return request<{
    pois: {
      name: string;
      location: string;
      address: string;
    }[];
  }>("https://restapi.amap.com/v3/place/text", {
    method: "get",
    params: {
      key: config.mapWebKey,
      keywords: keywords,
      city: city,
    },
  });
}
