import {
  Card,
  NavBar,
  Image,
  Steps,
  Input,
  Uploader,
  Button,
  Skeleton,
  Loading,
  Space,
} from "react-vant";
import styles from "./historyList.less";
import { history, useLocation } from "umi";
import { useEffect, useState } from "react";
import { getReportDetail } from "@/api";
const src = "https://img.yzcdn.cn/vant/cat.jpeg";

const historyDetail = () => {
  const location = useLocation();

  const { id } = location.state as any;

  const [dataSource, setDataSource] = useState<any>();
  const [loading, setLoading] = useState(true);
  useEffect(() => {
    setLoading(true);
    getReportDetail(id).then((res) => {
      if (res.data) {
        setDataSource(res.data);
        setTimeout(() => {
          setLoading(false);
        }, 200);
      }
    });
  }, [id]);
  return (
    <div className={styles.container}>
      {loading ? (
        <div className={styles.loadingBox}>
          <Loading type="spinner" color="#3f45ff">
            加载中...
          </Loading>
        </div>
      ) : (
        <div className={styles.content}>
          <div className={styles.item_title}>
            <div className={styles.item_title_name}>
              案件编号：{dataSource?.caseinfo?.MISSION_NUM}
            </div>

            <div className={styles.item_time}>
              {dataSource?.caseinfo?.INFORM_TIME}
            </div>
            <div className={styles.item_title_address}>
              {dataSource?.caseinfo?.ADDR}
            </div>
          </div>
          <div className={styles.item_content}>
            <p>{dataSource?.caseinfo?.PROBLEM_DESC}</p>
            <Space>
              {dataSource?.attachment?.map((v: any) => {
                return (
                  <Image
                    width="100"
                    height="100"
                    src={v.CASE_ATTACHMENT_PATH}
                  />
                );
              })}
            </Space>

            <Steps
              direction="vertical"
              active={dataSource?.process.length - 1}
              style={{ marginTop: 16 }}
            >
              {dataSource?.process?.map((v) => {
                return (
                  <Steps.Item>
                    <div>2016-07-12 12:40</div>
                    <p>
                      {v?.OPERATION_DESC ??
                        "尊敬的市民，您所反映的问题正在处理中"}
                    </p>
                    <p>案件状态：{v?.ACTION_NAME}</p>
                    <p>处理人：{v?.OPERATOR_NAME}</p>
                  </Steps.Item>
                );
              })}
            </Steps>
          </div>
        </div>
      )}
    </div>
  );
};

export default historyDetail;
