import {
  Card,
  NavBar,
  Image,
  Steps,
  Input,
  Uploader,
  Button,
  Loading,
} from "react-vant";
import styles from "./historyList.less";
import { history, useModel } from "umi";
import { useEffect, useState } from "react";
import { getReportList } from "@/api";
const src = "https://img.yzcdn.cn/vant/cat.jpeg";
const Item = ({ data }: { data: any }) => {
  return (
    <div
      className={styles.item}
      onClick={() => {
        history.push("/historyDetail", { id: data.CASE_INFO_ID });
      }}
    >
      <div className={styles.item_title}>
        <div className={styles.item_title_name}>
          案件编号：{data.MISSION_NUM}
        </div>

        <div className={styles.item_time}>{data.INFORM_TIME}</div>
        <div className={styles.item_title_address}>{data.ADDR}</div>
      </div>
      <div className={styles.item_content}>
        <div className={styles.item_content_desc}>{data.PROBLEM_DESC}</div>
        <div style={{ color: "green" }}>{data.rec_status}</div>
      </div>
    </div>
  );
};

const historyList = () => {
  const [pagination, setPagination] = useState({
    current: 1,
    pageSize: 10,
    end: false,
  });
  const [dataSource, setDataSource] = useState<any[]>([]);
  const { user } = useModel("global");
  useEffect(() => {
    initData();
  }, []);
  const initData = () => {
    if (pagination.end) {
      return;
    }
    if (pagination.current === 1) {
      setLoading(true);
    }
    getReportList(user.mobile, pagination.pageSize, pagination.current).then(
      (res) => {
        if (res.data.length === pagination.pageSize) {
          setPagination({
            ...pagination,
            current: pagination.current + 1,
          });
          if (res.data.length < pagination.pageSize) {
            setPagination({
              ...pagination,
              end: true,
            });
          }
        }
        setDataSource([...dataSource, ...res.data]);
        setTimeout(() => {
          setLoading(false);
        }, 200);
      }
    );
  };
  const [loading, setLoading] = useState(true);

  const onScroll = (e: React.UIEvent<HTMLDivElement, UIEvent>) => {
    /** 判断滚动到底部 */
    if (
      e.currentTarget.scrollTop + e.currentTarget.clientHeight >=
      e.currentTarget.scrollHeight - 30
    ) {
      if (!pagination.end) {
        initData();
      }
    }
  };
  return (
    <div className={styles.container}>
      {loading ? (
        <div className={styles.loadingBox}>
          <Loading type="spinner" color="#3f45ff">
            加载中...
          </Loading>
        </div>
      ) : (
        <div className={styles.content} onScroll={onScroll}>
          {dataSource.map((v) => {
            return <Item key={v.CASE_INFO_ID} data={v}></Item>;
          })}
        </div>
      )}
    </div>
  );
};

export default historyList;
